==> savane-1.0.3.1.tar.gz: savane/frontend/php/admin/index.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: index.php,v 1.22 2004/03/02 18:26:18 toddy Exp $
#
#
# Copyright 1999-2000 (c) The SourceForge Crew
#
#
#  Copyright (C) 2000, 2001, 2002, 2003 Free Software Foundation
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#
#
#

require "../include/pre.php";

site_admin_header(array('title'=>_("Home"),'toptab'=>'admhome'));

$abc_array = array('A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z','0','1','2','3','4','5','6','7','8','9');


print '<h3>'._("Warning").'</h3>';

print '<p>';
printf (_("Please read and fully understand the %s Savane Administrator Guide %s before doing anything here."),'<a href="' . $GLOBALS['sys_home'] . 'savannah.html">','</a>');
print '</p>';

print '<p class="warn">';
print _("These functions currently have minimal error checking, if any. They are fine to play with but may not act as expected if you leave fields blank, etc... Also, navigating the admin functions with the \"back\" button is highly unadvised.");
print '</p>';

print '<h3>'._("Site Statistics").'</h3>';

$title_arr=array();
$title_arr[]=_("Type");
$title_arr[]=_("Number");
$title_arr[]=_("Action");

print html_build_list_table_top ($title_arr);

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
db_query("SELECT count(*) AS count FROM user WHERE status='A'");
$row = db_fetch_array();
print '<td>'._("Registered active site users").'</td>';
print '<td>'.$row[count].'</td>';
print '<td></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups ");
$row = db_fetch_array();
print '<td>'._("Registered projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='A' ");
$row = db_fetch_array();
print '<td>'._("Active projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='P' ");
$row = db_fetch_array();
print '<td>'._("Pending projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td><a href="grouplist.php?status=P">'._("Browse").'</a></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='I' ");
$row = db_fetch_array();
print '<td>'._("Incompleted projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td><a href="grouplist.php?status=I">'._("Browse").'</a></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='D' ");
$row = db_fetch_array();
print '<td>'._("Deleted projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td><a href="grouplist.php?status=D">'._("Browse").'</a></td>';
print "</tr>\n";

print "</table>\n";

site_admin_footer(array());

?>

==> savane-1.0.5a.tar.gz: savane/frontend/php/admin/index.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: index.php,v 1.23 2004/09/22 08:11:50 yeupou Exp $
#
#
# Copyright 1999-2000 (c) The SourceForge Crew
#
#
#  Copyright (C) 2000, 2001, 2002, 2003 Free Software Foundation
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";

site_admin_header(array('title'=>_("Home"),'toptab'=>'admhome'));

print '<h3>'._("Warning").'</h3>';

print '<p class="warn">';
print _("Administrators functions currently have minimal error checking, if any. They are fine to play with but may not act as expected if you leave fields blank, etc... Also, navigating the admin functions with the \"back\" button is highly unadvised.");
print '</p>';


print '<h3>'._("Configuration").'</h3>';

print '<p>'.sprintf(_("The currently effective configuration file is %s."), getenv('SV_LOCAL_INC_PREFIX').'/savannah.conf').'</p>';

print '<p>';
print sprintf(_("It is highly recommended to make sure %s is correct, especially on a fresh install or after upgrade."), utils_link($GLOBALS['sys_home']."admin/group_type.php", _("Group Type Configuration")));
print '</p>';

print '<h3>'._("Site Statistics").'</h3>';

$title_arr=array();
$title_arr[]=_("Type");
$title_arr[]=_("Number");
$title_arr[]=_("Action");

print html_build_list_table_top ($title_arr);

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
db_query("SELECT count(*) AS count FROM user WHERE status='A'");
$row = db_fetch_array();
print '<td>'._("Registered active site users").'</td>';
print '<td>'.$row[count].'</td>';
print '<td></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups ");
$row = db_fetch_array();
print '<td>'._("Registered projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='A' ");
$row = db_fetch_array();
print '<td>'._("Active projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='P' ");
$row = db_fetch_array();
print '<td>'._("Pending projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td><a href="grouplist.php?status=P">'._("Browse").'</a></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='I' ");
$row = db_fetch_array();
print '<td>'._("Incompleted projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td><a href="grouplist.php?status=I">'._("Browse").'</a></td>';
print "</tr>\n";

print '<tr class="'.utils_get_alt_row_color($inc++).'">';
$res = db_query("SELECT count(*) AS count FROM groups WHERE status='D' ");
$row = db_fetch_array();
print '<td>'._("Deleted projects").'</td>';
print '<td>'.$row[count].'</td>';
print '<td><a href="grouplist.php?status=D">'._("Browse").'</a></td>';
print "</tr>\n";

print "</table>\n";

site_admin_footer(array());

?>
